Module: wine
Branch: master
Commit: 234f331dc898b065a78a3d1cf18bf7f040310406
URL: http://source.winehq.org/git/wine.git/?a=commit;h=234f331dc898b065a78a3d1cf…
Author: Francois Gouget <fgouget(a)free.fr>
Date: Thu Feb 16 23:30:39 2012 +0100
po: Fix some typography issues in the Dutch translation.
---
po/nl.po | 28 ++++++++++++++--------------
1 files changed, 14 insertions(+), 14 deletions(-)
diff --git a/po/nl.po b/po/nl.po
index f40ba99..def27c3 100644
--- a/po/nl.po
+++ b/po/nl.po
@@ -2015,7 +2015,7 @@ msgstr "Certificaatbeleid"
#: cryptdlg.rc:28
msgid "Policy Identifier: "
-msgstr "Autoriteits Sleutel Identificatie nummer:"
+msgstr "Autoriteits Sleutel Identificatie nummer: "
#: cryptdlg.rc:29
msgid "Policy Qualifier Info"
@@ -2312,6 +2312,7 @@ msgstr ""
"authenticatie en om berichten te ondertekenen. Een certificaatkluis bevat "
"een verzameling van certificaten, lijsten van herroepen certificaten en "
"lijsten van vertrouwde certificaten.\n"
+"\n"
"Klik Volgende om verder te gaan."
#: cryptui.rc:381
@@ -8388,9 +8389,8 @@ msgid "The specified device handle is invalid."
msgstr "De gespecificeerde apparaatverwijzing is ongeldig."
#: winmm.rc:34
-#, fuzzy
msgid "There is no driver installed on your system!"
-msgstr "Er is geen driver geïnstalleerd op uw systeem !\n"
+msgstr "Er is geen driver geïnstalleerd op uw systeem!"
#: winmm.rc:35 winmm.rc:61
msgid ""
@@ -9235,7 +9235,7 @@ msgstr ""
#: attrib.rc:28 cmd.rc:318
msgid "%1: File Not Found\n"
-msgstr "%1 : Bestand niet gevonden\n"
+msgstr "%1: Bestand niet gevonden\n"
#: attrib.rc:47
msgid ""
@@ -9460,9 +9460,9 @@ msgid ""
msgstr ""
"IF wordt gebruikt om een opdracht voorwaardelijk uit te voeren.\n"
"\n"
-"Syntax:\tIF [NOT] EXIST bestandsnaam opdracht\n"
-"IF [NOT] tekenreeks1==tekenreeks2 opdracht\n"
-"IF [NOT] ERRORLEVEL getal opdracht\n"
+"Syntax: IF [NOT] EXIST bestandsnaam opdracht\n"
+" IF [NOT] tekenreeks1==tekenreeks2 opdracht\n"
+" IF [NOT] ERRORLEVEL getal opdracht\n"
"\n"
"In de tweede vorm van de opdracht moeten tekenreeks1 en tekenreeks2 tussen\n"
"dubbele aanhalingstekens staan. De vergelijking is niet gevoelig voor het\n"
@@ -9543,7 +9543,8 @@ msgstr ""
"toets in te drukken.\n"
"\n"
"Dit is vooral handig in batchbestanden om de gebruiker in staat te stellen "
-"om de uitvoer van een voorafgaande opdracht te bekijken, voordat het van het "
+"om\n"
+"de uitvoer van een voorafgaande opdracht te bekijken, voordat het van het\n"
"scherm schuift.\n"
#: cmd.rc:149
@@ -9761,7 +9762,7 @@ msgid ""
"ENDLOCAL ends localization of environment changes in a batch file\n"
"which were introduced by a preceding SETLOCAL.\n"
msgstr ""
-"ENDLOCAL beëindigt de localisatie van omgevingswijzigingen in een "
+"ENDLOCAL beëindigt de localisatie van omgevingswijzigingen in een\n"
"batchbestand die werd begonnen door een voorafgaande SETLOCAL opdracht.\n"
#: cmd.rc:233
@@ -9845,8 +9846,7 @@ msgstr ""
#: cmd.rc:259
msgid "MORE displays output of files or piped input in pages.\n"
msgstr ""
-"MORE toont de uitvoer van programma's of herleidde invoer\n"
-"per bladzijde.\n"
+"MORE toont de uitvoer van programma's of herleidde invoer per bladzijde.\n"
#: cmd.rc:263
msgid ""
@@ -12937,7 +12937,7 @@ msgstr "Standaardinstellingen"
#: winecfg.rc:59
msgid "Wine Programs (*.exe; *.exe.so)"
-msgstr "Wine toepassingen (*.exe, *.exe.so)"
+msgstr "Wine toepassingen (*.exe; *.exe.so)"
#: winecfg.rc:60
msgid "Use global settings"
@@ -13348,9 +13348,9 @@ msgid ""
msgstr ""
" --backend={user|curses} Kiezen voor user zal een nieuw window doen "
"verschijnen,\n"
-" curses zal proberen de huidige terminal om te "
+" curses zal proberen de huidige terminal om te "
"zetten\n"
-" in een Wine console.\n"
+" in een Wine console.\n"
#: wineconsole.rc:50
msgid " <command> The Wine program to launch in the console.\n"
Module: wine
Branch: master
Commit: 46d4bec269203be8f88cb791f8feb39f86c1014b
URL: http://source.winehq.org/git/wine.git/?a=commit;h=46d4bec269203be8f88cb791f…
Author: Christian Costa <titan.costa(a)gmail.com>
Date: Fri Feb 17 00:19:12 2012 +0100
d3dxof: Decompress all MSZIP chunks of the compressed file and update file format description.
---
dlls/d3dxof/parsing.c | 60 ++++++++++++++++++++++++++++++-------------
dlls/d3dxof/tests/d3dxof.c | 9 +++---
2 files changed, 47 insertions(+), 22 deletions(-)
diff --git a/dlls/d3dxof/tests/d3dxof.c b/dlls/d3dxof/tests/d3dxof.c
index 8ce22b7..5c6315a 100644
--- a/dlls/d3dxof/tests/d3dxof.c
+++ b/dlls/d3dxof/tests/d3dxof.c
@@ -74,11 +74,12 @@ static char empty_bin_file[] = "xof 0302bin 0064";
/* MSZip data is generated with the command "MAKECAB.EXE /D Compress=ON /D CompressionType=MSZip file packed"
* Data in cab is after the filename (null terminated) and the 32-bit checksum:
* size (16-bit), packed_size (16-bit) and compressed data (with leading 16-bit CK signature)
- * Data in x files is preceding by 2 16-bit words: size with xof header (16 bytes) and a 0 value
- * It does not seem possible to generate a MSZip data with no byte, so put just 1 byte here */
-/* "\n" packed with MSZip => not text */
+ * for each MSZIP chunk whose decompressed size can not exceed 32768 bytes
+ * Data in x files is preceeding by the size (32-bit) of the decompressed file including the xof header (16 bytes)
+ * It does not seem possible to generate a MSZip data chunk with no byte, so put just 1 byte here */
+/* "\n" packed with MSZip => no text */
static char empty_tzip_file[] = "xof 0302tzip0064\x11\x00\x00\x00\x01\x00\x05\x00\x43\x4b\xe3\x02\x00";
-/* "\n" packed with MSZip => not token (token are 16-bit and there is only 1 byte) */
+/* "\n" packed with MSZip => no token (token are 16-bit and there is only 1 byte) */
static char empty_bzip_file[] = "xof 0302bzip0064\x11\x00\x00\x00\x01\x00\x05\x00\x43\x4b\xe3\x02\x00";
static char empty_cmp_file[] = "xof 0302cmp 0064";
static char empty_xxxx_file[] = "xof 0302xxxx0064";
diff --git a/dlls/d3dxof/parsing.c b/dlls/d3dxof/parsing.c
index 4b9b12f..a6e387d 100644
--- a/dlls/d3dxof/parsing.c
+++ b/dlls/d3dxof/parsing.c
@@ -220,40 +220,64 @@ HRESULT parse_header(parse_buffer * buf, BYTE ** decomp_buffer_ptr)
if (header[2] == XOFFILE_FORMAT_BINARY_MSZIP || header[2] == XOFFILE_FORMAT_TEXT_MSZIP)
{
/* Extended header for compressed data:
* 16-17 -> decompressed size w/ header, 18-19 -> null,
* 20-21 -> decompressed size w/o header, 22-23 -> size of MSZIP compressed data,
* 24-xx -> compressed MSZIP data */
int err;
- WORD decomp_size;
- WORD comp_size;
+ DWORD decomp_file_size;
+ WORD decomp_chunk_size;
+ WORD comp_chunk_size;
LPBYTE decomp_buffer;
- buf->rem_bytes -= sizeof(WORD) * 2;
- buf->buffer += sizeof(WORD) * 2;
- if (!read_bytes(buf, &decomp_size, sizeof(decomp_size)))
- return DXFILEERR_BADFILETYPE;
- if (!read_bytes(buf, &comp_size, sizeof(comp_size)))
+ if (!read_bytes(buf, &decomp_file_size, sizeof(decomp_file_size)))
return DXFILEERR_BADFILETYPE;
- TRACE("Compressed format %s detected: compressed_size = %x, decompressed_size = %x\n",
- debugstr_fourcc(header[2]), comp_size, decomp_size);
+ TRACE("Compressed format %s detected: decompressed file size with xof header = %d\n",
+ debugstr_fourcc(header[2]), decomp_file_size);
+
+ /* Does not take xof header into account */
+ decomp_file_size -= 16;
- decomp_buffer = HeapAlloc(GetProcessHeap(), 0, decomp_size);
+ decomp_buffer = HeapAlloc(GetProcessHeap(), 0, decomp_file_size);
if (!decomp_buffer)
{
ERR("Out of memory\n");
return DXFILEERR_BADALLOC;
}
- err = mszip_decompress(comp_size, decomp_size, (char*)buf->buffer, (char*)decomp_buffer);
- if (err)
+ *decomp_buffer_ptr = decomp_buffer;
+
+ while (buf->rem_bytes)
{
- WARN("Error while decompressing mszip archive %d\n", err);
+ if (!read_bytes(buf, &decomp_chunk_size, sizeof(decomp_chunk_size)))
+ return DXFILEERR_BADFILETYPE;
+ if (!read_bytes(buf, &comp_chunk_size, sizeof(comp_chunk_size)))
+ return DXFILEERR_BADFILETYPE;
+
+ TRACE("Process chunk: compressed_size = %d, decompressed_size = %d\n",
+ comp_chunk_size, decomp_chunk_size);
+
+ err = mszip_decompress(comp_chunk_size, decomp_chunk_size, (char*)buf->buffer, (char*)decomp_buffer);
+ if (err)
+ {
+ WARN("Error while decompressing MSZIP chunk %d\n", err);
HeapFree(GetProcessHeap(), 0, decomp_buffer);
return DXFILEERR_BADALLOC;
+ }
+ buf->rem_bytes -= comp_chunk_size;
+ buf->buffer += comp_chunk_size;
+ decomp_buffer += decomp_chunk_size;
}
+
+ if ((decomp_buffer - *decomp_buffer_ptr) != decomp_file_size)
+ ERR("Size of all decompressed chunks (%u) does not match decompressed file size (%u)\n",
+ (DWORD)(decomp_buffer - *decomp_buffer_ptr), decomp_file_size);
+
/* Use decompressed data */
- buf->buffer = *decomp_buffer_ptr = decomp_buffer;
- buf->rem_bytes = decomp_size;
+ buf->buffer = *decomp_buffer_ptr;
+ buf->rem_bytes = decomp_file_size;
}
TRACE("Header is correct\n");
@@ -220,40 +220,64 @@ HRESULT parse_header(parse_buffer * buf, BYTE ** decomp_buffer_ptr)
{
/* Extended header for compressed data:
- * 16-17 -> decompressed size w/ header, 18-19 -> null,
- * 20-21 -> decompressed size w/o header, 22-23 -> size of MSZIP compressed data,
- * 24-xx -> compressed MSZIP data */
+ * 16-19 -> size of decompressed file including xof header,
+ * 20-21 -> size of first decompressed MSZIP chunk, 22-23 -> size of first compressed MSZIP chunk
+ * 24-xx -> compressed MSZIP data chunk
+ * xx-xx -> size of next decompressed MSZIP chunk, xx-xx -> size of next compressed MSZIP chunk
+ * xx-xx -> compressed MSZIP data chunk
+ * .............................................................................................. */
int err;